<?php
// admin/forums/forum_user_manager.php

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
require_once __DIR__ . '/forum_bootstrap.php';
require_once __DIR__ . '/../auth.php';
requireLogin();

$current = currentUser();
if ((int)$current['group_id'] < 9) {
    exit('Unauthorized');
}

require_once __DIR__ . '/../../config/db.php';

// Search and pagination settings
$perPage = 20;
$search = trim($_REQUEST['search'] ?? '');
$page = isset($_REQUEST['page']) && is_numeric($_REQUEST['page']) && $_REQUEST['page'] > 0 ? (int)$_REQUEST['page'] : 1;
$offset = ($page - 1) * $perPage;
$searchParam = "%{$search}%";

// Get total user count matching search
$countStmt = $db->prepare(
    "SELECT COUNT(*) AS cnt
     FROM forum_users
     WHERE username LIKE ? OR email LIKE ?"
);
$countStmt->bind_param('ss', $searchParam, $searchParam);
$countStmt->execute();
$countRes = $countStmt->get_result();
$totalRow = $countRes->fetch_assoc();
$totalUsers = (int)$totalRow['cnt'];
$totalPages = max(1, (int)ceil($totalUsers / $perPage));
$countStmt->close();

// Handle delete user
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_user'])) {
    $delId = (int)$_POST['delete_user'];
    $delStmt = $db->prepare("DELETE FROM forum_users WHERE id = ?");
    $delStmt->bind_param('i', $delId);
    $delStmt->execute();
    $delStmt->close();
    $message = "Deleted user with ID {$delId}.";
}
// Handle bulk update
elseif ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['bulk_update'])) {
    $userIds = $_POST['user_ids'] ?? [];
    $newGroup = (int)($_POST['new_group_id'] ?? 0);
    if ($newGroup && count($userIds)) {
        $updateStmt = $db->prepare("UPDATE forum_users SET group_id = ? WHERE id = ?");
        foreach ($userIds as $uid) {
            $updateStmt->bind_param('ii', $newGroup, $uid);
            $updateStmt->execute();
        }
        $updateStmt->close();
        $message = "Updated " . count($userIds) . " user(s) to new group.";
    }
}

// Fetch users matching search for current page
$userStmt = $db->prepare(
    "SELECT id, username, email, group_id
     FROM forum_users
     WHERE username LIKE ? OR email LIKE ?
     ORDER BY username
     LIMIT ? OFFSET ?"
);
$userStmt->bind_param('ssii', $searchParam, $searchParam, $perPage, $offset);
$userStmt->execute();
$userRes = $userStmt->get_result();
$users = [];
while ($row = $userRes->fetch_assoc()) {
    $users[] = $row;
}
$userStmt->close();

// Fetch usergroups
$groups = [];
$groupRes = $db->query("SELECT id, name FROM forum_usergroups WHERE is_deleted = 0 ORDER BY name");
while ($g = $groupRes->fetch_assoc()) {
    $groups[$g['id']] = $g['name'];
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Forum User Manager</title>
    <link rel="stylesheet" href="../css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Forum User Manager</h1>

    <?php if (!empty($message)): ?>
        <div class="alert success"><?= htmlspecialchars($message) ?></div>
    <?php endif; ?>

    <!-- Search Form -->
    <form method="get" class="search-form">
        <input type="text" name="search" placeholder="Search by username or email" value="<?= htmlspecialchars($search) ?>">
        <button type="submit">Search</button>
    </form>

    <!-- User List / Actions -->
    <form method="POST">
        <input type="hidden" name="search" value="<?= htmlspecialchars($search) ?>">
        <input type="hidden" name="page" value="<?= $page ?>">
        <table class="data-table">
            <thead>
                <tr>
                    <th><input type="checkbox" id="select_all"></th>
                    <th>Username</th>
                    <th>Email</th>
                    <th>Current Group</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($users as $u): ?>
                    <tr>
                        <td><input type="checkbox" name="user_ids[]" value="<?= $u['id'] ?>"></td>
                        <td><?= htmlspecialchars($u['username']) ?></td>
                        <td><?= htmlspecialchars($u['email']) ?></td>
                        <td><?= htmlspecialchars($groups[$u['group_id']] ?? 'Unknown') ?></td>
                        <td>
                            <a href="edit_user_permissions.php?user_id=<?= $u['id'] ?>">Edit Permissions</a>
                            <button type="submit" name="delete_user" value="<?= $u['id'] ?>" formnovalidate onclick="return confirm('Delete user <?= htmlspecialchars($u['username'], ENT_QUOTES) ?>? This cannot be undone.');">Delete</button>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <div class="bulk-action">
            <label for="new_group_id">Move selected users to group:</label>
            <select name="new_group_id" id="new_group_id" required>
                <option value="">-- Select Group --</option>
                <?php foreach ($groups as $gid => $gname): ?>
                    <option value="<?= $gid ?>"><?= htmlspecialchars($gname) ?></option>
                <?php endforeach; ?>
            </select>
            <button type="submit" name="bulk_update">Apply</button>
        </div>
    </form>

    <!-- Pagination -->
    <div class="pagination">
        <?php if ($page > 1): ?>
            <a href="?page=<?= $page - 1 ?>&search=<?= urlencode($search) ?>">&laquo; Previous</a>
        <?php endif; ?>

        <?php for ($p = 1; $p <= $totalPages; $p++): ?>
            <?php if ($p == $page): ?>
                <span class="current"><?= $p ?></span>
            <?php else: ?>
                <a href="?page=<?= $p ?>&search=<?= urlencode($search) ?>"><?= $p ?></a>
            <?php endif; ?>
        <?php endfor; ?>

        <?php if ($page < $totalPages): ?>
            <a href="?page=<?= $page + 1 ?>&search=<?= urlencode($search) ?>">Next &raquo;</a>
        <?php endif; ?>
    </div>
</div>

<script>
// Select/deselect all checkboxes
document.getElementById('select_all').addEventListener('change', function() {
    document.querySelectorAll('input[name="user_ids[]"]').forEach(cb => cb.checked = this.checked);
});
</script>
</body>
</html>
