<?php
// user_content/forum-registration.php

if (session_status() === PHP_SESSION_NONE) session_start();

require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

$error = $success = '';

$socials = [
  'discord', 'facebook', 'instagram', 'threads', 'twitter', 'bluesky',
  'tiktok', 'twitch', 'youtube_url', 'website_url'
];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username   = trim($_POST['username'] ?? '');
    $email      = trim($_POST['email'] ?? '');
    $password   = trim($_POST['password'] ?? '');
    $name       = trim($_POST['name'] ?? '');
    $birthday   = trim($_POST['birthday'] ?? '') ?: null;
    $avatar     = trim($_POST['avatar_url'] ?? '');
    $signature  = trim($_POST['signature'] ?? '');
    $bio        = trim($_POST['bio'] ?? '');

    $socialVals = [];
    foreach ($socials as $s) {
        $socialVals[$s] = trim($_POST[$s] ?? '');
    }

    if (!$username || !$email || !$password || !$name || !$birthday) {
        $error = "All required fields must be filled out.";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "Invalid email address.";
    } elseif (strlen($bio) > 300) {
        $error = "Bio must be 300 characters or less.";
    } else {
        $hashed = password_hash($password, PASSWORD_DEFAULT);

        // Map eMS group to forum group
        $eMSGroup = (int)($_SESSION['group_id'] ?? 0);
        if (in_array($eMSGroup, [9, 10], true)) {
            // eMS Admin (9) or Webmaster (10)
            $forumGroup = 4;
        } else {
            // Default forum group for regular users
            $forumGroup = 1;
        }

        $sql = "INSERT INTO forum_users
                (username, email, password_hash, name, birthday, avatar_url, signature, bio,
                 discord, facebook, instagram, threads, twitter, bluesky, tiktok, twitch,
                 youtube_url, website_url, group_id, joined_at)
                VALUES
                (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())";

        $stmt = $db->prepare($sql);
        $stmt->bind_param(
            str_repeat('s', 18) . 'i',
            $username,
            $email,
            $hashed,
            $name,
            $birthday,
            $avatar,
            $signature,
            $bio,
            $socialVals['discord'],
            $socialVals['facebook'],
            $socialVals['instagram'],
            $socialVals['threads'],
            $socialVals['twitter'],
            $socialVals['bluesky'],
            $socialVals['tiktok'],
            $socialVals['twitch'],
            $socialVals['youtube_url'],
            $socialVals['website_url'],
            $forumGroup
        );

        if ($stmt->execute()) {
            $success = "Registration successful. You may now log in.";
        } else {
            $error = "Registration failed: " . $stmt->error;
        }
        $stmt->close();
    }
}
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title>Forum Registration</title>
  <link rel="stylesheet" href="/css/forum.css">
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>

</head>
<body>
<div class="forum-profile edit">
<div class="breadcrumbs">
        <a href="/forums">Forums</a> &raquo;
        Registration
    </div>
  <h1>Register for the Forum</h1>

  <?php if ($error): ?>
    <div class="form-error"><?= htmlspecialchars($error) ?></div>
  <?php elseif ($success): ?>
    <div class="form-success"><?= htmlspecialchars($success) ?></div>
  <?php endif; ?>

  <form method="POST" class="profile-edit-form">
    <div class="form-row">
      <label for="username">Username*</label>
      <input type="text" name="username" id="username" required>
    </div>

    <div class="form-row">
      <label for="email">Email*</label>
      <input type="email" name="email" id="email" required>
    </div>

    <div class="form-row">
      <label for="password">Password*</label>
      <input type="password" name="password" id="password" required>
    </div>

    <div class="form-row">
      <label for="name">Display Name*</label>
      <input type="text" name="name" id="name" required>
    </div>

    <div class="form-row">
      <label for="birthday">Birthday*</label>
      <input type="date" name="birthday" id="birthday" required>
    </div>

    <div class="form-row">
      <label for="avatar_url">Avatar URL</label>
      <input type="url" name="avatar_url" id="avatar_url">
    </div>

    <div class="form-row">
      <label for="signature">Signature</label>
      <textarea name="signature" id="signature" rows="3"></textarea>
    </div>

    <div class="form-row">
      <label for="bio">Short Bio (300 characters max)</label>
      <textarea name="bio" id="bio" maxlength="300" rows="3"></textarea>
    </div>

    <?php foreach ($socials as $s): 
      $label = ucfirst(
        $s === 'twitter' ? 'Twitter/X' :
        ($s === 'youtube_url' ? 'YouTube' :
        ($s === 'website_url' ? 'Website' : $s)));
    ?>
    <div class="form-row">
      <label for="<?= $s ?>"><?= $label ?> Username</label>
      <input type="text" name="<?= $s ?>" id="<?= $s ?>">
    </div>
    <?php endforeach; ?>

    <div class="form-row">
      <button type="submit" class="btn">Register</button>
    </div>
  </form>
</div>
</body>
</html>
