<?php
// user_content/forums.php — forum index with information box styled as category box

ob_start();
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../functions/functions.php';

// Permission check
if (!hasForumPermission('can_view_topics')) {
    die("You do not have permission to view the forums.");
}

// Handle login
$forumUser  = $_SESSION['forum_user'] ?? null;
$loginError = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['username'], $_POST['password'])) {
    $username = trim($_POST['username']);
    $password = $_POST['password'];

    // Try forum user
    $stmt = $db->prepare("SELECT * FROM forum_users WHERE username = ?");
    $stmt->bind_param('s', $username);
    $stmt->execute();
    $user = $stmt->get_result()->fetch_assoc();
    $stmt->close();

    // eMS bridge
    if (!$user) {
        $ems = $db->prepare("SELECT id, username, email, password_hash FROM users WHERE username = ?");
        $ems->bind_param('s', $username);
        $ems->execute();
        $emsUser = $ems->get_result()->fetch_assoc();
        $ems->close();
        if ($emsUser && !empty($emsUser['password_hash']) && password_verify($password, $emsUser['password_hash'])) {
            // create forum user if missing
            $chk = $db->prepare("SELECT id FROM forum_users WHERE ems_user_id = ?");
            $chk->bind_param('i', $emsUser['id']);
            $chk->execute();
            $exists = $chk->get_result()->fetch_assoc();
            $chk->close();
            if (!$exists) {
                $hash = password_hash($password, PASSWORD_DEFAULT);
                $ins = $db->prepare(
                    "INSERT INTO forum_users (ems_user_id, username, email, password_hash, joined_at) VALUES (?, ?, ?, ?, NOW())"
                );
                $ins->bind_param('isss', $emsUser['id'], $emsUser['username'], $emsUser['email'], $hash);
                $ins->execute();
                $ins->close();
            }
            // reload forum user
            $rl = $db->prepare("SELECT * FROM forum_users WHERE ems_user_id = ?");
            $rl->bind_param('i', $emsUser['id']);
            $rl->execute();
            $user = $rl->get_result()->fetch_assoc();
            $rl->close();
        }
    }

    // verify
    if ($user && !empty($user['password_hash']) && password_verify($password, $user['password_hash'])) {
        $_SESSION['forum_user'] = $user;
        if (!empty($_POST['remember_me'])) {
            setcookie('forum_username', $username, time()+86400*30, '/');
        } else {
            setcookie('forum_username','',time()-3600,'/');
        }
        $to = $_SESSION['forum_return_to'] ?? '/forums';
        unset($_SESSION['forum_return_to']);
        echo "<script>window.location.replace('".htmlspecialchars($to,ENT_QUOTES)."');</script>";
        exit;
    } else {
        $loginError = 'Invalid username or password.';
    }
}

// fetch categories
$catQ = $db->prepare("SELECT id,name,slug,description FROM forum_categories WHERE parent_id IS NULL AND is_deleted=0 ORDER BY sort_order,name");
$catQ->execute();
$cats = $catQ->get_result()->fetch_all(MYSQLI_ASSOC);
$catQ->close();

$subQ = $db->prepare("SELECT id,parent_id,name,slug FROM forum_categories WHERE parent_id IS NOT NULL AND is_deleted=0 ORDER BY parent_id,sort_order,name");
$subQ->execute();
$rawSubs = $subQ->get_result()->fetch_all(MYSQLI_ASSOC);
$subQ->close();
$subs=[];
foreach ($rawSubs as $r) {
    $subs[$r['parent_id']][] = $r;
}

function getAllCategoryIds($db, $parentId) {
    $ids = [$parentId];
    $stmt = $db->prepare("SELECT id FROM forum_categories WHERE parent_id = ? AND is_deleted=0");
    $stmt->bind_param('i', $parentId);
    $stmt->execute();
    $children = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
    $stmt->close();
    foreach ($children as $child) {
        // Recursively include grandchildren
        $ids = array_merge($ids, getAllCategoryIds($db, $child['id']));
    }
    return $ids;
}

// Info
$total = (int)$db->query("SELECT COUNT(*) FROM forum_users")->fetch_row()[0];
$cutoff = date('Y-m-d H:i:s', time() - 86400);
// active
$aQ = $db->prepare("SELECT DISTINCT fu.username FROM forum_posts p JOIN forum_users fu ON fu.id=p.user_id WHERE p.created_at>=?");
$aQ->bind_param('s', $cutoff);
$aQ->execute();
$active = array_column($aQ->get_result()->fetch_all(MYSQLI_ASSOC), 'username');
$aQ->close();
if ($forumUser && !in_array($forumUser['username'], $active)) {
    $active[] = $forumUser['username'];
}
$ac = count($active);
// registered
$rQ = $db->prepare("SELECT username FROM forum_users WHERE joined_at>=?");
$rQ->bind_param('s', $cutoff);
$rQ->execute();
$reg = array_column($rQ->get_result()->fetch_all(MYSQLI_ASSOC), 'username');
$rQ->close();
$rC = count($reg);
// birthdays
$bRes = $db->query("SELECT username FROM forum_users WHERE MONTH(birthday)=MONTH(CURDATE()) AND DAY(birthday)=DAY(CURDATE())");
$b = array_column($bRes->fetch_all(MYSQLI_ASSOC), 'username');
$bC = count($b);
// last topic
$lt = $db->query("SELECT title,slug,created_at FROM forum_topics WHERE is_deleted=0 ORDER BY created_at DESC LIMIT 1")->fetch_assoc();
// last post
$lp = $db->query(
    "SELECT p.created_at AS post_time, fu.username, t.title, t.slug
     FROM forum_posts p
     JOIN forum_topics t ON t.id=p.topic_id AND t.is_deleted=0
     JOIN forum_users fu ON fu.id=p.user_id
     WHERE p.is_deleted=0 ORDER BY p.created_at DESC LIMIT 1"
)->fetch_assoc();
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title>Forum Index</title>
  <link rel="stylesheet" href="/css/forum.css">
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
</head>
<body>
<div class="forum-user-panel">
  <?php if (isForumLoggedIn()): $u = currentForumUser(); ?>
    <div class="welcome">
      Hello, <a href="/forums/user/<?=urlencode($u['username'])?>"><font color="white"><?=htmlspecialchars($u['username'])?></font></a> |
      <a href="/forums/user/edit"><font color="white">Edit Profile</font></a> |
      <a href="/forums/logout"><font color="white">Sign Out</font></a>
    </div>
  <?php else: ?>
    <form method="post" action="/forums" class="login-form">
      <?php if ($loginError): ?><div class="form-error"><?=htmlspecialchars($loginError)?></div><?php endif; ?>
      <label><input type="text" name="username" placeholder="Username" required value="<?=htmlspecialchars($_COOKIE['forum_username']??'')?>"></label><br>
      <label><input type="password" name="password" placeholder="Password" required></label><br>
      <label><input type="checkbox" name="remember_me"> Remember Me</label>
      <button type="submit">Login</button>
      <div class="links"><a href="/forum-registration"><font color="white">Register</font></a> | <a href="#"><font color="white">Forgot Password?</font></a></div>
    </form>
  <?php endif; ?>
</div>
<table class="forum-table">
  <thead><tr><th>Forum</th><th>Latest Topics</th></tr></thead>
  <tbody>
    <?php foreach ($cats as $c):
      $ids = getAllCategoryIds($db, $c['id']);
      $idL = implode(',', array_map('intval', $ids));
      $tc  = $db->query("SELECT COUNT(*) FROM forum_topics WHERE category_id IN($idL) AND is_deleted=0")->fetch_row()[0];
      $pc  = $db->query("SELECT COUNT(*) FROM forum_posts p JOIN forum_topics t ON t.id=p.topic_id WHERE t.category_id IN($idL) AND p.is_deleted=0")->fetch_row()[0];
      $lat = $db->query(
          "SELECT t.title,t.slug,fu.username,p.created_at
           FROM forum_posts p
           JOIN forum_topics t ON t.id=p.topic_id AND t.is_deleted=0
           LEFT JOIN forum_users fu ON fu.id=p.user_id
           WHERE t.category_id IN($idL) AND p.is_deleted=0 ORDER BY p.created_at DESC LIMIT 2"
      )->fetch_all(MYSQLI_ASSOC);
    ?>
    <tr class="parent-forum">
      <td>
        <i class="fas fa-folder"></i> <a href="/forums/<?=htmlspecialchars($c['slug'])?>"><?=htmlspecialchars($c['name'])?></a>
        <?php if ($c['description']): ?><div class="desc"><?=htmlspecialchars($c['description'])?></div><?php endif; ?>
        <div class="counts"><small><?= $tc ?> Threads &bull; <?= $pc ?> Posts</small></div>
        <?php if (!empty($subs[$c['id']])): ?><div class="subforums"><?php foreach ($subs[$c['id']] as $s): ?><i class="fas fa-folder-open"></i> <a href="/forums/<?=htmlspecialchars($s['slug'])?>"><?=htmlspecialchars($s['name'])?></a><?php endforeach;?></div><?php endif; ?>
      </td>
      <td class="latest">
        <?php if (count($lat)): foreach ($lat as $l): ?>
          <div class="topic-line">
            <a href="/forums/topic/<?=htmlspecialchars($l['slug'])?>"><?=htmlspecialchars($l['title'])?></a>
            <div class="meta">by <?=htmlspecialchars($l['username']?:'Guest')?> on <?=date('M j, Y', strtotime($l['created_at']))?> at <?=date('g:i A', strtotime($l['created_at']))?></div>
          </div>
        <?php endforeach; else: ?>
          <div class="no-posts">No posts yet</div>
        <?php endif; ?>
      </td>
    </tr>
    <?php endforeach; ?>
    <tr class="parent-forum">
      <td colspan="2">
        <div class="forum-info-box" style="text-align:left;">
          <h2><i class="fas fa-info-circle"></i> Forum Information</h2>
          <ul>
            <li><strong>Total Users:</strong> <?= $total ?></li>
            <li><strong>Active (24h):</strong> <?= $ac ?><?php if ($ac): ?> (<?php foreach ($active as $i => $au): ?><?= $i ? ', ' : ' ' ?><a href="/forums/user/<?=urlencode($au)?>"><?=htmlspecialchars($au)?></a><?php endforeach; ?>)<?php endif; ?></li>
            <li><strong>Registered (24h):</strong> <?= $rC ?><?php if ($rC): ?> (<?php foreach ($reg as $i => $ru): ?><?= $i ? ', ' : ' ' ?><a href="/forums/user/<?=urlencode($ru)?>"><?=htmlspecialchars($ru)?></a><?php endforeach; ?>)<?php endif; ?></li>
            <li><strong>Birthdays:</strong> <?= $bC ?><?php if ($bC): ?> (<?= htmlspecialchars(implode(', ', $b)) ?>)<?php endif; ?></li>
            <li><strong>Last Topic:</strong> <a href="/forums/topic/<?=htmlspecialchars($lt['slug'])?>"><?=htmlspecialchars($lt['title'])?></a> on <?=date('M j, Y', strtotime($lt['created_at']))?> at <?=date('g:i A', strtotime($lt['created_at']))?></li>
            <li><strong>Latest Post:</strong> in <a href="/forums/topic/<?=htmlspecialchars($lp['slug'])?>"><?=htmlspecialchars($lp['title'])?></a> by <?=htmlspecialchars($lp['username'])?> on <?=date('M j, Y', strtotime($lp['post_time']))?> at <?=date('g:i A', strtotime($lp['post_time']))?></li>
          </ul>
        </div>
      </td>
    </tr>
  </tbody>
</table>
</body>
</html>
