<?php
// user_content/new_topic.php

// 1) Bridge into forum_users
require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';

// 2) Database config
require_once __DIR__ . '/../config/db.php';

$forumUser = $_SESSION['forum_user'] ?? null;

// 3) Determine category by slug
if (empty($_GET['slug'])) {
    echo "<p>Category not specified.</p>";
    exit;
}
$stmt = $db->prepare("SELECT id, name, slug FROM forum_categories WHERE slug = ? AND is_deleted = 0");
$stmt->bind_param('s', $_GET['slug']);
$stmt->execute();
$category = $stmt->get_result()->fetch_assoc();
if (!$category) {
    echo "<p>Category not found.</p>";
    exit;
}

// 4) Ensure user is logged into forum and has permission to post topics
if (!isForumLoggedIn()) {
    echo "<p>You must be logged in to create a topic.</p>";
    exit;
}

if (!hasForumPermission('can_post_topic')) {
    echo "<p>Your user group does not have permission to create new topics.</p>";
    exit;
}

$forumUser = currentForumUser();
$userId = (int) $forumUser['id'];

// Slug generator helper
function generateUniqueSlug($db, $baseSlug) {
    $slug = $baseSlug;
    $i = 1;
    $check = $db->prepare("SELECT COUNT(*) FROM forum_topics WHERE slug = ?");
    do {
        $check->bind_param('s', $slug);
        $check->execute();
        $check->bind_result($count);
        $check->fetch();
        $check->reset();

        if ($count > 0) {
            $slug = $baseSlug . '-' . $i++;
        }
    } while ($count > 0);
    $check->close();
    return $slug;
}

// 5) Handle form submission
$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title   = trim($_POST['title'] ?? '');
    $content = trim($_POST['content'] ?? '');

    if ($title === '' || $content === '') {
        $error = "Both title and content are required.";
    } else {
        $slugBase = preg_replace('#[^a-z0-9-]#', '-', strtolower($title));
        $slugBase = preg_replace('#-+#', '-', $slugBase);
        $slugText = generateUniqueSlug($db, $slugBase);

        // Insert topic
        $insTopic = $db->prepare("INSERT INTO forum_topics (category_id, user_id, title, slug) VALUES (?, ?, ?, ?)");
        $insTopic->bind_param('iiss', $category['id'], $userId, $title, $slugText);
        $insTopic->execute();
        $topicId = $db->insert_id;

        // Insert first post
        $insPost = $db->prepare("INSERT INTO forum_posts (topic_id, user_id, content) VALUES (?, ?, ?)");
        $insPost->bind_param('iis', $topicId, $userId, $content);
        $insPost->execute();

        // Client-side redirect to clear POST
        $url = "/forums/topic/{$slugText}?id={$topicId}";
        echo "<script>window.location.replace('{$url}');</script>";
        exit;
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>New Topic in <?= htmlspecialchars($category['name']) ?></title>
    <script src="/js/tinymce/tinymce.min.js" referrerpolicy="origin"></script>
<link
  rel="stylesheet"
  href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
  integrity="sha512-p+w1Xb...YOUR_INTEGRITY_HASH...=="
  crossorigin="anonymous"
  referrerpolicy="no-referrer"
/>

</head>
<body>
<div class="forum-new-topic">
    <div class="breadcrumbs">
        <a href="/forums">Forums</a> &raquo;
        <a href="/forums/<?= htmlspecialchars($category['slug']) ?>"><?= htmlspecialchars($category['name']) ?></a> &raquo;
        New Topic
    </div>

    <h1>New Topic in “<?= htmlspecialchars($category['name']) ?>”</h1>
    <?php if ($error): ?>
        <p class="error"><?= htmlspecialchars($error) ?></p>
    <?php endif; ?>

    <form method="POST">
        <div>
            <label for="title">Title:</label><br>
            <input type="text" id="title" name="title" value="<?= htmlspecialchars($_POST['title'] ?? '') ?>" required>
        </div>
        <div>
            <label for="content">Content:</label><br>
            <textarea id="content" name="content"><?= htmlspecialchars($_POST['content'] ?? '') ?></textarea>
        </div>
        <button type="submit">Create Topic</button>
        <a href="/forums/<?= htmlspecialchars($category['slug']) ?>">Cancel</a>
    </form>
</div>

<script src="/js/tinymce/tinymce.min.js" referrerpolicy="origin"></script>
<script>
document.addEventListener('DOMContentLoaded', () => {
  tinymce.init({
    selector: 'textarea',
    height: 400,
    menubar: 'file edit view insert format tools table help',
    plugins: [
      'advlist', 'autolink', 'lists', 'link', 'image', 'charmap', 'preview',
      'anchor', 'searchreplace', 'visualblocks', 'code', 'fullscreen',
      'insertdatetime', 'media', 'table', 'code', 'help', 'wordcount', 'emoticons', 'hr'
    ],
    toolbar: [
      'undo redo | blocks | bold italic underline strikethrough removeformat | alignleft aligncenter alignright alignjustify',
      'bullist numlist outdent indent | link media table hr emoticons charmap | code fullscreen preview help'
    ],
    branding: false,
    license_key: 'gpl',
    content_style: 'body { font-family:Helvetica,Arial,sans-serif; font-size:14px }',
    setup: function (editor) {
      editor.on('change', function () {
        editor.save();
      });
    }
  });

  const form = document.querySelector('form');
  if (form) {
    form.addEventListener('submit', function (e) {
      tinymce.triggerSave();
      const content = document.getElementById('content');
      if (content && (!content.value.trim() || content.value.trim() === '<p><br></p>')) {
        alert("Content is required.");
        e.preventDefault();
      }
    });
  }
});
</script>
</body>
</html>
