<?php
// user_content/view_user.php — updated to show only forum-specific fields with styled social icons and resolved usergroup name

if (session_status() === PHP_SESSION_NONE) session_start();
require_once __DIR__ . '/../admin/forums/forum_bootstrap.php';
require_once __DIR__ . '/../config/db.php';

if (!hasForumPermission('can_view_topics')) {
    echo "<p>You do not have permission to view user profiles.</p>";
    exit;
}

if (empty($_GET['slug'])) {
    echo "<p>User not specified.</p>";
    exit;
}
$stmt = $db->prepare("SELECT * FROM forum_users WHERE username = ?");
$stmt->bind_param('s', $_GET['slug']);
$stmt->execute();
$user = $stmt->get_result()->fetch_assoc();
if (!$user) {
    echo "<p>User not found.</p>";
    exit;
}
$forumId = (int)$user['id'];

$groupName = 'Unknown';
if (!empty($user['group_id'])) {
    $gstmt = $db->prepare("SELECT name FROM forum_usergroups WHERE id = ?");
    $gstmt->bind_param('i', $user['group_id']);
    $gstmt->execute();
    $gstmt->bind_result($groupNameResult);
    if ($gstmt->fetch()) {
        $groupName = $groupNameResult;
    }
    $gstmt->close();
}

$topicStmt = $db->prepare("SELECT COUNT(*) FROM forum_topics WHERE user_id = ? AND is_deleted = 0");
$topicStmt->bind_param('i', $forumId);
$topicStmt->execute();
$topicStmt->bind_result($topicCount);
$topicStmt->fetch();
$topicStmt->close();

$postStmt = $db->prepare("SELECT COUNT(*) FROM forum_posts WHERE user_id = ?");
$postStmt->bind_param('i', $forumId);
$postStmt->execute();
$postStmt->bind_result($postCount);
$postStmt->fetch();
$postStmt->close();

$recentStmt = $db->prepare("SELECT t.title, t.slug, p.created_at FROM forum_posts p JOIN forum_topics t ON t.id = p.topic_id WHERE p.user_id = ? ORDER BY p.created_at DESC LIMIT 10");
$recentStmt->bind_param('i', $forumId);
$recentStmt->execute();
$recent = $recentStmt->get_result()->fetch_all(MYSQLI_ASSOC);

$me = currentForumUser();
$isOwner = $me && $me['id'] === $forumId;

function socBadge($url, $iconClass) {
    return '<a href="' . htmlspecialchars($url) . '" target="_blank" style="background: var(--forum-bg); padding: 6px; margin: 2px; border-radius: 4px; display: inline-block;"><i class="' . $iconClass . '" style="font-size:14px;"></i></a>';
}
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title><?= htmlspecialchars($user['username']) ?>’s Profile</title>
  <link rel="stylesheet" href="/css/forum.css">
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css">
</head>
<body>
  <div class="card forum-topic">
    <div class="forum-header">
      <div class="breadcrumbs">
        <a href="/forums">Forums</a> &raquo; User Profile<p><br>
      </div>
      <h1><?= htmlspecialchars($user['username']) ?>’s Profile</h1>
      <?php if ($isOwner): ?>
        <a href="/forums/user/edit" class="btn forum-bg" title="Edit Your Profile">
          <i class="fas fa-pencil-alt"></i> Edit Profile
        </a>
      <?php endif; ?>
    </div>

    <div class="post-row original-post">
      <div class="post-content">
        <div class="meta">
          <p><strong>Display Name:</strong> <?= htmlspecialchars($user['name'] ?? $user['username']) ?></p>
          <p><strong>Email:</strong> <?= htmlspecialchars($user['email']) ?></p>
          <p><strong>Birthday:</strong> <?= htmlspecialchars($user['birthday'] ?? 'N/A') ?></p>
          <p><strong>Last Seen:</strong> <?= $user['last_seen'] ? date('M j, Y g:ia', strtotime($user['last_seen'])) : 'Never' ?></p>
          <p><strong>Total Topics:</strong> <?= $topicCount ?> | <strong>Total Posts:</strong> <?= $postCount ?></p>
        </div>

        <?php if ($user['bio']): ?>
        <div class="bio-block">
          <h3>About Me</h3>
          <p><?= nl2br(htmlspecialchars($user['bio'])) ?></p>
        </div>
        <?php endif; ?>

        <?php if ($user['signature']): ?>
        <div class="signature"><?= nl2br(htmlspecialchars($user['signature'])) ?></div>
        <?php endif; ?>

        <?php if (!empty($recent)): ?>
          <p><h2>Recent Posts</h2>
          <ul>
          <?php foreach ($recent as $r): ?>
            <li>
              <a href="/forums/topic/<?= htmlspecialchars($r['slug']) ?>" class="forum-bg">
                <?= htmlspecialchars($r['title']) ?>
              </a>
              on <?= date('M j, Y g:ia', strtotime($r['created_at'])) ?>
            </li>
          <?php endforeach; ?>
          </ul>
        <?php endif; ?>
      </div>
      <div class="post-userbox">
        <img src="<?= htmlspecialchars($user['avatar_url'] ?: '/images/default-avatar.png') ?>" alt="Avatar" class="profile-avatar">
        <div class="user-meta">
          <strong><?= htmlspecialchars($user['name']) ?></strong>
          <i><?= htmlspecialchars($groupName) ?></i>
        </div>
        <?php if (
          !empty($user['discord']) || !empty($user['facebook']) || !empty($user['instagram']) || !empty($user['threads']) ||
          !empty($user['twitter']) || !empty($user['bluesky']) || !empty($user['tiktok']) || !empty($user['twitch']) ||
          !empty($user['youtube_url']) || !empty($user['website_url'])
        ): ?>
        <div class="social-icons">
          <?php
          if (!empty($user['discord']))    echo socBadge('#', 'fab fa-discord');
          if (!empty($user['facebook']))    echo socBadge("https://facebook.com/{$user['facebook']}", 'fab fa-facebook');
          if (!empty($user['instagram']))   echo socBadge("https://instagram.com/{$user['instagram']}", 'fab fa-instagram');
          if (!empty($user['threads']))     echo socBadge("https://www.threads.net/{$user['threads']}", 'fa-solid fa-hashtag');
          if (!empty($user['twitter']))     echo socBadge("https://x.com/{$user['twitter']}", 'fab fa-twitter');
          if (!empty($user['bluesky']))     echo socBadge("https://bsky.app/profile/{$user['bluesky']}", 'fa-solid fa-link');
          if (!empty($user['tiktok']))      echo socBadge("https://tiktok.com/@{$user['tiktok']}", 'fab fa-tiktok');
          if (!empty($user['twitch']))      echo socBadge("https://twitch.tv/{$user['twitch']}", 'fab fa-twitch');
          if (!empty($user['youtube_url'])) echo socBadge($user['youtube_url'], 'fab fa-youtube');
          if (!empty($user['website_url'])) echo socBadge($user['website_url'], 'fa-solid fa-globe');
          ?>
        </div>
        <?php endif; ?><p><br>Member since <?= date('M j, Y', strtotime($user['joined_at'])) ?>
      </div>
    </div>
  </div>
</body>
</html>
